markdown-peek-0.1.1 is not a library.
Markdown Peek
Markdown Peek (mdpeek) is a lightweight CLI tool that watches a markdown file and renders it either in your browser (live preview) or directly in the terminal.
Features
- ⚡ Fast
- 🔄 Live Reload
- ⚙️ Easy Configure
- 🌐🖥️ Preview in Browser or in Terminal
- 📝 Supported Github Flavored Markdown(GFM), GitLab Flavored Markdown(GLFM)
Quick start
Preview on your browser
mdpeek detects README.md on default and previews markdown on browser.
Preview on your terminal
mdpeek detects README.md on default.
If you want preview on termianl, using term subcommand.
Installation
cargo
cargo install markdown-peek
nix(Planed)
nix-shell -p markdown-peek --command mdpeek
npm(Planed)
npm install -g markdown-peek
download prebuild-binary
curl -SL https://github.com/takeshid/markdown-peek
Status
GFM
- Table
- TaskList
- Strike throough
- Fenced Code
- Syntax Hightlight
- Emoji
- Alert
- MathJax
- Color Model
- Auto Link
- InPage Link
- Footnote
- Table of Contents
- Theme Switch(Light/Dark)
GLFM(Planed)
- Table
- Strike throough
- TaskList
- Fence Code
- Syntax Hightlight
- Auto Link
- Emoji
- Alert
- Math equation
Terminal
- Table
- TaskList
- Strike throough
- Fenced Code
- Syntax Hightlight
- Emoji
- Alert
- MathJax
- Color Model
- Auto Link
- InPage Link
- Footnote
- Table of Contents
License
MIT License. See LICENSE.